@@ -29,7 +29,7 @@ def is_loop_key(key):
         return False
 
 
-def map_json(mapping_config, json_data):
+def map_json(mapping_config, json_data, strict=False):
     result = {}
 
     for key, config in mapping_config.iteritems():
@@ -39,7 +39,7 @@ def map_json(mapping_config, json_data):
             if is_loop_key(key):
                 key, prop = get_loop_params(key)
                 list_result = []
-                list_json = walk_dict(json_data, key, True)
+                list_json = walk_dict(json_data, key, strict)
                 for lj in list_json:
                     list_result.append(
                         map_json(config, lj)
@@ -47,13 +47,13 @@ def map_json(mapping_config, json_data):
                 result[prop] = list_result
             else:
                 result.update(
-                    map_json(config, walk_dict(json_data, key, True))
+                    map_json(config, walk_dict(json_data, key, strict))
                 )
         elif str == type(config):
             if is_loop_key(key):
                 key, prop = get_loop_params(key)
                 list_result = []
-                list_json = walk_dict(json_data, key, True)
+                list_json = walk_dict(json_data, key, strict)
                 for lj in list_json:
                     list_result.append(
                         lj[config]
